@@ -8,8 +8,9 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::LcdProc;
-
-our $VERSION='2.038';
+{
+  $Config::Model::LcdProc::VERSION = '2.039';
+}
 
 1;
 
@@ -21,18 +22,18 @@ Config::Model::LcdProc - Edit and validate LcdProc configuration file
 
 =head1 VERSION
 
-version 0.001
+version 2.039
 
 =head1 SYNOPSIS
 
 =head2 invoke editor
 
-The following command must be run in a package source directory. When
-run, L<cme> will load C</etc/LCDd.conf> and launch a graphical editor:
+The following command will load C</etc/LCDd.conf> and launch a
+graphical editor:
 
  cme edit lcdproc
 
-=head2 Just check lcdproc files
+=head2 Just check lcdproc configuration
 
 You can also use L<cme> to run sanity checks on the configuration file:
 
@@ -53,24 +54,6 @@ configuration file of LcdProc, i.e. C</etc/LCDd.conf>.
 This module can also be used to modify safely the content of this file
 from a Perl programs.
 
-=head1 user interfaces
-
-As mentioned in L<cme>, several user interfaces are available:
-
-=over
-
-=item *
-
-A graphical interface is proposed by default if L<Config::Model::TkUI>
-is installed.
-
-=item *
-
-A L<Fuse> virtual file system with option C<< cme fusefs lcdproc -fuse_dir <mountpoint> >> 
-if L<Fuse> is installed (Linux only)
-
-=back
-
 =head1 AUTHOR
 
 Dominique Dumont, (dod at debian dot org)
@@ -81,6 +64,10 @@ Dominique Dumont, (dod at debian dot org)
 
 =item *
 
+http://lcdproc.omnipotent.net/
+
+=item *
+
 L<cme>
 
 =item *
